==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { MovingAverageConvergenceDivergenceIndicatorDescription } from "./MovingAverageConvergenceDivergenceIndicatorDescription";
/**
 * @hidden
 */
export let MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a == null) {
                MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.c(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a);
            }
            if (a.k(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("ShortPeriod", "Number:int");
            a.item("LongPeriod", "Number:int");
            a.item("SignalPeriod", "Number:int");
        }
        static d(a) {
            MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.b(a);
            a.ad("MovingAverageConvergenceDivergenceIndicator", () => new MovingAverageConvergenceDivergenceIndicatorDescription());
            a.ac("MovingAverageConvergenceDivergenceIndicator", MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a);
        }
    }
    MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.$t = markType(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata, 'MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata');
    MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a = null;
    return MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { MovingAverageConvergenceDivergenceIndicatorDescription } from "./MovingAverageConvergenceDivergenceIndicatorDescription";
/**
 * @hidden
 */
export let MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a == null) {
                MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.c(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a);
            }
            if (a.k(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("ShortPeriod", "Number:int");
            a.item("LongPeriod", "Number:int");
            a.item("SignalPeriod", "Number:int");
        }
        static d(a) {
            MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.b(a);
            a.ae("MovingAverageConvergenceDivergenceIndicator", () => new MovingAverageConvergenceDivergenceIndicatorDescription());
            a.ad("MovingAverageConvergenceDivergenceIndicator", MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a);
        }
    }
    MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.$t = markType(MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata, 'MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata');
    MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata.a = null;
    return MovingAverageConvergenceDivergenceIndicatorDescriptionMetadata;
})();
